# ifndef yyCodeGeneration
# define yyCodeGeneration

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"


extern void (* CodeGeneration_Exit) ARGS ((void));

extern void NodeAdapt ARGS ((tTree t));

extern void BeginCodeGeneration ARGS ((void));
extern void CloseCodeGeneration ARGS ((void));

# endif
